@@ -140,6 +140,24 @@ cal_plot <- function(spct,
     counts.label <- ""
   }
 
+  if (!is.na(ylim[1])) {
+    y.min <- ylim[1]
+    spct[["irrad.mult"]] <- ifelse(spct[["irrad.mult"]] < y.min,
+                                   NA_real_,
+                                   spct[["irrad.mult"]])
+  } else {
+    y.min <- min(spct[["irrad.mult"]], 0, na.rm = TRUE)
+  }
+
+  if (!is.na(ylim[2])) {
+    y.max <- ylim[2]
+    spct[["irrad.mult"]] <- ifelse(spct[["irrad.mult"]] > y.max,
+                                   NA_real_,
+                                   spct[["irrad.mult"]])
+  } else {
+    y.max <- max(spct[["s.e.irrad"]], 0, y.min, na.rm = TRUE)
+  }
+
   if (num.mult.cols > 1L) {
     spct <- photobiology::spct_wide2long(spct = spct, idfactor = "scan")
     plot <- ggplot(spct) + aes(x = .data[["w.length"]], y = .data[["irrad.mult"]], linetype = .data[["scan"]])
@@ -160,13 +178,6 @@ cal_plot <- function(spct,
     annotations <- temp$annotations
   }
 
-  y.min <- ifelse(!is.na(ylim[1]),
-                  ylim[1],
-                  min(spct[["irrad.mult"]], 0, na.rm = TRUE))
-  y.max <- ifelse(!is.na(ylim[2]),
-                  ylim[2],
-                  max(spct[["irrad.mult"]], 0, na.rm = TRUE))
-
   # We want data plotted on top of the boundary lines
   if ("boundaries" %in% annotations) {
     if (y.min < -0.01 * y.max) {
@@ -207,7 +218,7 @@ cal_plot <- function(spct,
       length(intersect(c("boxes", "segments", "labels",
                          "summaries", "colour.guide", "reserve.space"),
                        annotations)) > 0L) {
-    y.limits <- c(y.min, y.max * 1.25)
+    y.limits <- c(y.min, y.min + (y.max - y.min) * 1.25)
     x.limits <- c(min(spct) - wl_expanse(spct) * 0.025, NA) # NA needed because of rounding errors
   } else {
     y.limits <- c(y.min, y.max)
