@@ -113,6 +113,24 @@ cps_plot <- function(spct,
     cps.label <- ""
   }
 
+  if (!is.na(ylim[1])) {
+    y.min <- ylim[1]
+    spct[["cps"]] <- ifelse(spct[["cps"]] < y.min,
+                            NA_real_,
+                            spct[["cps"]])
+  } else {
+    y.min <- min(spct[["cps"]], 0, na.rm = TRUE)
+  }
+
+  if (!is.na(ylim[2])) {
+    y.max <- ylim[2]
+    spct[["cps"]] <- ifelse(spct[["cps"]] > y.max,
+                            NA_real_,
+                            spct[["cps"]])
+  } else {
+    y.max <- max(spct[["cps"]], y.min, 0, na.rm = TRUE)
+  }
+
   if (num.cps.cols > 1L) {
     spct <- photobiology::spct_wide2long(spct = spct, idfactor = "scan")
     plot <- ggplot(spct, aes(x = .data[["w.length"]], y = .data[["cps"]], linetype = .data[["scan"]]))
@@ -133,13 +151,6 @@ cps_plot <- function(spct,
     annotations <- temp$annotations
   }
 
-  y.min <- ifelse(!is.na(ylim[1]),
-                  ylim[1],
-                  min(c(spct[["cps"]], 0), na.rm = TRUE))
-  y.max <- ifelse(!is.na(ylim[2]),
-                  ylim[2],
-                  max(c(spct[["cps"]], 0), na.rm = TRUE))
-
   # We want data plotted on top of the boundary lines
   if ("boundaries" %in% annotations) {
     if (y.min < (-0.01 * y.max)) {
@@ -182,7 +193,7 @@ cps_plot <- function(spct,
 
   if (!is.null(annotations) &&
       length(intersect(c("boxes", "segments", "labels", "summaries", "colour.guide", "reserve.space"), annotations)) > 0L) {
-    y.limits <- c(y.min, y.max * 1.25)
+    y.limits <- c(y.min, y.min + (y.max - y.min) * 1.25)
     x.limits <- c(min(spct) - wl_expanse(spct) * 0.025, NA) # NA needed because of rounding errors
   } else {
     y.limits <- c(y.min, y.max)
